Clubs management — SoL 4 user manual

# Clubs management

A club is the entity that organizes one or more championships of tourneys. It can also have a list of associated players.

A club may also be a national federation, which usually coordinates the clubs of a particular country. Often the international tourneys are hosted by this or that federation in turn and usually it is mandatory for a player to be affiliated with a particular federation before she can participate to an event.

Contents

- Clubs management

  - Menu actions

  - Insert and edit

    - Description

    - Nationality, web site and email

    - Federation

    - Pairing method and bounties

    - Owner

## Menu actions

In addition to the standard actions the menu at the top contains the following items:

Clubs management

Championship

  Opens the management of the championships organized by the selected club

Players

  Opens the management of the players associated with the selected club

Download

  Downloads an archive of all the tourneys organized by the selected club

Assign

  Change the ownership of the selected clubs: you can select one or more clubs keeping pressed the `Ctrl` key and extend the selection with the `Shift` key

The administrator and the user that owns a club may find one further action in the popup menu that appears right clicking on the particular club:

Users

  Opens the user association management window, allowing to select which other users may create entities linked to the club, in particular new tournaments.

## Insert and edit

### Description

Each club has a description, that must be unique: there cannot be two distinct clubs with the same description.

### Nationality, web site and email

The nationality, the web site URL and the email are optional. The latter may be used to send email messages to the responsible for the club.

### Federation

A club may be marked as a federation: to be accepted at international events it is often mandatory for a player to be affiliated with a national federation.

### Pairing method and bounties

The pairing method and the prize-giving method are used as default values when new championships are added to the club.

### Owner

The user who is responsible of the club data, usually the one that inserted that particular record: the information related to the club are changeable only by him (and also by the administrator of the system).

The emblem field may contain the name of an image file (either a `.png`, a `.gif`, or `.jpg`) that will printed on the Badges. Although it will be scaled as needed, it's recommended to put there a reasonably sized logo (the application imposes a 256Kb limit).